(find-first coll func)(handle-request ctx {:keys [url method] :as req} & rest)Each request contained :method :url pair and response :body. Optionally there might be :req which is body of request that has to me matched
Each request contained :method :url pair and response :body. Optionally there might be :req which is body of request that has to me matched
(is-match {:keys [url method body]} v)(map-body-to-edn traffic)(mock-http responses & body)(mock-http-ctx ctx responses & body)(record-traffic req)(remove-at coll idx)(responses)(traffic)(traffic n)(verify-traffic y)(verify-traffic-edn y)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |